#
# spec file for package lalinference
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
%else
%bcond_with test
%define psuffix %{nil}
%endif

%define pname lalinference

%define shlib lib%{name}23
# octave >= 6 not supported
%bcond_with octave

Name:           %{pname}%{?psuffix}
Version:        4.1.7
Release:        2.3
Summary:        LSC Algorithm Inference Library
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Physics
URL:            https://wiki.ligo.org/Computing/DASWG/LALSuite
Source:         https://software.igwn.org/sources/source/lalsuite/%{pname}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM lalinference-printf-data-type-consistency.patch badshah400@gmail.com -- Cast data passed to printf from size_t to long to make it consistent with the format "%li"; this fixes build failures on i586
Patch0:         lalinference-printf-data-type-consistency.patch
# PATCH-FIX-UPSTREAM
Patch1:         https://git.ligo.org/lscsoft/lalsuite/-/commit/9dba245ab3692ecf691247a442704f13c075ed34.patch#/lalinference-swig-stringval-not-value.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel >= 1.7}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  swig
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(lal) >= 7.2.0
BuildRequires:  pkgconfig(lalburst) >= 1.6.0
BuildRequires:  pkgconfig(lalframe) >= 2.0.0
BuildRequires:  pkgconfig(lalinspiral) >= 3.0.0
BuildRequires:  pkgconfig(lalmetaio) >= 3.0.0
BuildRequires:  pkgconfig(lalsimulation) >= 4.0.0
# SECTION For tests
%if %{with test}
BuildRequires:  %{python_module Shapely}
BuildRequires:  %{python_module astropy}
BuildRequires:  %{python_module glue >= 1.54.1}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module healpy >= 1.9.1}
BuildRequires:  %{python_module lal >= 7.2.0}
BuildRequires:  %{python_module lalburst >= 1.6.0}
BuildRequires:  %{python_module lalframe >= 2.0.0}
BuildRequires:  %{python_module lalinspiral >= 3.0.0}
BuildRequires:  %{python_module lalmetaio >= 3.0.0}
BuildRequires:  %{python_module lalsimulation >= 4.0.0}
BuildRequires:  %{python_module matplotlib >= 1.2.0}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module py}
BuildRequires:  %{python_module scipy >= 0.9.0}
BuildRequires:  pkgconfig(lalinference) = %{version}
%endif
# /SECTION
%if %{with octave}
BuildRequires:  octave-lal
BuildRequires:  octave-lalframe
BuildRequires:  octave-lalinspiral
BuildRequires:  octave-lalmetaio
BuildRequires:  octave-lalpulsar
BuildRequires:  octave-lalsimulation
BuildRequires:  pkgconfig(octave)
%endif
Requires:       %{name}-data = %{version}
Requires:       python-lal >= 7.2.0
Requires:       python-lalburst >= 1.6.0
Requires:       python-lalframe >= 2.0.0
Requires:       python-lalinspiral >= 3.0.0
Requires:       python-lalmetaio >= 3.0.0
Requires:       python-lalsimulation >= 4.0.0
ExcludeArch:    %{ix86}

%python_subpackages

%description
The LSC Algorithm Inference Library for gravitational wave data analysis.

%package -n %{shlib}
Summary:        Shared library for LAL Inference
Group:          System/Libraries
Conflicts:      liblalinference21

%description -n %{shlib}
This package contains the shared-object libraries needed to run applications
that use the LAL Inference library.

%package -n %{name}-devel
Summary:        Development files for LAL Inference
Group:          Development/Libraries/C and C++
Requires:       %{name}-data = %{version}
Requires:       %{shlib} = %{version}
Requires:       pkgconfig(gsl)
Requires:       pkgconfig(lal) >= 7.2.0
Requires:       pkgconfig(lalburst) >= 1.6.0
Requires:       pkgconfig(lalframe) >= 2.0.0
Requires:       pkgconfig(lalinspiral) >= 3.0.0
Requires:       pkgconfig(lalmetaio) >= 3.0.0
Requires:       pkgconfig(lalsimulation) >= 4.0.0

%description -n %{name}-devel
This package contains sources and header files needed to build applications
that use the LAL Inference library.

%package -n %{name}-data
Summary:        Data files for lalinference
Group:          Productivity/Scientific/Physics
Provides:       %{python_module lalinference-data}
BuildArch:      noarch

%description -n %{name}-data
This package provides the data files for lalinference.

%if %{with octave}
%package -n octave-lalinference
Summary:        Octave bindings for LAL Inference
Group:          Productivity/Scientific/Physics
Requires:       %{name}-data = %{version}
Requires:       octave-lal
Requires:       octave-lalburst
Requires:       octave-lalframe
Requires:       octave-lalinspiral
Requires:       octave-lalmetaio
Requires:       octave-lalpulsar
Requires:       octave-lalsimulation
%requires_eq    octave-cli

%description -n octave-lalinference
This package provides the necessary files for using LAL Inference with octave.
%endif

%prep
# Upstream commits are -p1 against the full lalsuite, but -p2 against individual lal* pkgs
# Patch0 is not upstream and uses -p1, so we have a mix of -p1 and -p2 patches
%autosetup -N -n %{pname}-%{version}
%patch -P0 -p1
%patch -P1 -p2

%build
%{python_expand # Necessary to run %%configure with all python flavors
export PYTHON=%{_bindir}/$python
mkdir ../$python
cp -pr ./ ../$python
pushd ../$python
%configure \
  %{?with_octave:--enable-swig-octave} \
  %{!?with_octave:--disable-swig-octave}
%make_build %{?with_test:test}
popd
}

%install
%if %{without test}
%{python_expand # install for all python flavors
export PYTHON=%{_bindir}/$python
pushd ../$python
%make_install
popd
}

# SECTION EXPORT LAL SPECIFIC ENV VARIABLES
# We do not use upstream's env files because they also set more generic
# variables (e.g. PATH) which may ruin setups

# NUKE UPSTREAM ENV SCRIPTS
rm %{buildroot}%{_sysconfdir}/%{name}-user-env.*

cat << EOF >> %{name}.sh
export LALINFERENCE_PREFIX=%{_prefix}
export LALINFERENCE_DATADIR=%{_datadir}/%{name}
EOF

cat << EOF >> %{name}.csh
setenv LALINFERENCE_PREFIX "%{_prefix}"
setenv LALINFERENCE_DATADIR "%{_datadir}/%{name}"
EOF

cat << EOF >> %{name}.fish
set LALINFERENCE_PREFIX (echo "%{_prefix}" | %{_bindir}/sed -e 's| |:|g;')
set LALINFERENCE_DATADIR (echo "%{_datadir}/%{name}" | %{_bindir}/sed -e 's| |:|g;')
EOF

install -D -m0644 %{name}.sh %{buildroot}%{_sysconfdir}/profile.d/%{name}.sh
install -D -m0644 %{name}.csh %{buildroot}%{_sysconfdir}/profile.d/%{name}.csh
install -D -m0644 %{name}.fish %{buildroot}%{_sysconfdir}/profile.d/%{name}.fish

# /SECTION

# SECTION REMOVE STATIC LIB AND LIBTOOL ARCHIVE
find %{buildroot}%{_libdir}/ -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print
# /SECTION

%{python_expand # FIX env HASHBANGS
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" %{buildroot}%{$python_sitearch}/lalinference/tiger/make_injtimes.py
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" %{buildroot}%{$python_sitearch}/lalinference/tiger/omegascans_dag.py
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" %{buildroot}%{$python_sitearch}/lalinference/tiger/postproc.py
}

sed -E -i "1 s|^#\!\s*%{_bindir}/env\s*bash|#\!/bin/bash|" %{buildroot}%{_bindir}/lalinference_mpi_wrapper

%python_expand %fdupes %{buildroot}%{$python_sitearch}/%{name}/

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/*.so.*

%files -n %{name}-devel
%doc AUTHORS README.md
%license COPYING
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%config %{_sysconfdir}/profile.d/%{name}.*

%if %{with octave}
%files -n octave-%{name}
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%endif

%files %{python_files}
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
%{_bindir}/*
%endif
%{python_sitearch}/lalinference/

%files -n %{name}-data
%{_datadir}/%{name}/

%else

%check
%{python_expand # check for all python flavors
export PYTHON=%{_bindir}/$python
%make_build -C ../$python check
}

%endif

%changelog
* Mon Dec  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add lalinference-swig-stringval-not-value.patch: For
  compatibility with swig 4.3.0, prefer 'stringval' before 'value'
  attribute (upstream commit 9dba245a).
* Thu Sep 12 2024 Atri Bhattacharya <badshah400@gmail.com>
- Drop upstreamed patches:
  * 0001-Replace-SafeConfigParser-with-ConfigParser.patch
  * lalinference-scipy-1_14-compat.patch
* Wed Sep 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.1.7 (no release notes).
* Sat Jul 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.1.6:
  * No release notes.
- Add lalinference-scipy-1_14-compat.patch -- Account for name
  changes of trapezoidal functions in scipy.integrate for scipy >=
  1.14
* Fri Mar  1 2024 Ben Greiner <code@bnavigator.de>
- Add 0001-Replace-SafeConfigParser-with-ConfigParser.patch
  for Python 3.12 compatibility
* Mon Jan 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.1.5:
  * No release notes.
* Tue May 23 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.1.3:
  * No release notes.
* Sun Feb 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add python-py BuildRequires to fix tests that fail due to "No
  module named 'py._path'" errors.
* Tue Aug 23 2022 Atri Bhattacharya <badshah400@gmail.com>
- Fix multibuild package names.
* Fri Aug 19 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.0:
  * No release notes.
- Drop lalinference-import-MutableMapping.patch: incorporated
  upstream.
- Drop BuildRequires on lalpulsar-devel and python-lalpulsar
  (indeed now lalpulsar depends on lalinference-devel).
- Update source URL.
- Update so version to match upstream.
- Re-organise list of BuildRequires to differentiate packages
  needed for building proper vs those needed for tests only.
- Tests can take a long time, split testing as part of %%check
  into its own _multibuild flavour.
- Make %%{name}-data a noarch package.
- New BuildRequires for tests: python-h5py.
* Tue Apr 26 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "liblalinference21.x86_64: E:
  shlib-policy-name-error SONAME: liblalinference.so.22, expected
  package suffix: 22"
* Sun Jan 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add lalinference-import-MutableMapping.patch --
  lalinference.wrapper: Update import of MutableMapping; patch
  taken from upstream commit.
* Sun Jan  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.1:
  * No release notes.
* Wed Nov 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build for %%ix86: lal is not available on this platform.
* Fri Feb 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.7 (no release notes).
* Mon Feb 15 2021 Benjamin Greiner <code@bnavigator.de>
- Update requirements and fix provider for data package
* Fri Feb 12 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.0.6
  * no changelog
* Sat Feb  6 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable python2 bindings.
* Fri Jan 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix test for multi-version python.
- Disable building for python3.6 as astropy isn't supported for
  python < 3.7.
* Mon Jan 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave bindings, since octave >= 6 isn't supported.
- Implement %%check section and run tests.
* Fri Oct 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.4:
  * Open HDF5 file in write mode when writing samples.
  * lalinference_pipe: Do not ENFORCE the use of a queue if it is
    specified in the .sub file.
* Tue Aug 11 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.3:
  * No release notes.
- Update required version of lalsimulation to 2.2.0.
* Tue Jul  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.1:
  * No release notes.
- Bump so number in shlib package name.
- Re-enable octave bindings: fixed upstream.
- Drop libtool from BuildRequires and do not run autoreconf
  before configure: these have not been needed since
  lalinference-build-octave44-with-swig3.patch was dropped.
* Wed Jul  1 2020 Atri Bhattacharya <badshah400@gmail.com>
- Disable octave support as compilation error with current swig.
* Fri May 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add lalinference-printf-data-type-consistency.patch: Cast data
  passed to printf from size_t to long to make it consistent with
  the format "%%li"; this fixes build failures on i586 (patch
  applicable on any arch).
* Wed Apr 22 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.11.7:
  * O3b point release
- Drop lalinference-build-octave44-with-swig3.patch: incorporated
  upstream.
- BuildRequires: python-xml only for openSUSE <= 15.2 since
  python2 is disabled for newer openSUSE.
- Package binaries for python3 only.
* Mon Feb  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.11.4:
  * O3b release.
- Rebase lalinference-build-octave44-with-swig3.patch for update.
* Tue Oct  1 2019 Atri Bhattacharya <badshah400@gmail.com>
- Build packages for both python2 and python3.
- Move binaries to the python2 subpackage.
- Split out a separate -data pkg used by all the lalinference
  binaries.
* Mon Jul 22 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.11.2:
  * O3 release.
- Update shared lib package names in keeping with upstream so
  versioning.
- Rebase lalinference-build-octave44-with-swig3.patch to conform
  to upstream's reworking for swig and octave version tests.
* Fri Feb  8 2019 badshah400@gmail.com
- Switch builds to python2; add python-xml to BuildRequires.
* Thu Feb  7 2019 badshah400@gmail.com
- Update Requires for octave-%%{name}.
* Sun Jan 27 2019 badshah400@gmail.com
- Add lalinference-build-octave44-with-swig3.patch: allow building
  octave bindings with swig 3.0.x rather than requiring swig 4.x.
* Sun Jan 27 2019 badshah400@gmail.com
- Initial package
